@@ -7,9 +7,12 @@ class Page:
         self.auth_needed = auth_needed
         self.builder = builder
     
-    def as_list(self, param=''):
+    def as_list(self, param='', all_params=None):
         def call_builder():
-            if len(signature(self.builder).parameters) > 0:
+            num_func_params = len(signature(self.builder).parameters)
+            if num_func_params > 1:
+                return self.builder(param, all_params)
+            elif num_func_params > 0:
                 return self.builder(param)
             else:
                 return self.builder()
